@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apachex.tcl,v 1.3 1999/04/17 09:07:10 jfontain Exp $}
+set rcsId {$Id: apachex.tcl,v 1.5 1999/07/20 19:05:55 jfontain Exp $}
 
-package provide apachex 1.1
-package require apacheutilities
+package provide apachex 1.2
+package require apacheutilities 1.1
 
 namespace eval apachex {
 
@@ -40,8 +40,10 @@ namespace eval apachex {
     proc initialize {optionsName} {
         upvar $optionsName options
         variable url
+        variable data
 
-        set url [::apache::url options apache]
+        set url [::apache::url options host apachex]
+        set data(identifier) apachex($host)
     }
 
     proc update {} {
