@@ -1,11 +1,11 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.18 1999/02/26 20:51:04 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.20 1999/07/23 21:26:40 jfontain Exp $}
 
 
-package provide arp 1.5
-package require network 1.2
+package provide arp 1.6
+package require network 1.3
 
 namespace eval arp {
 
@@ -36,6 +36,8 @@ namespace eval arp {
         if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
             set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
             foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
+            network::checkRemoteOutputEmptiness $remote(host)
+            set data(identifier) arp($remote(host))
             set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/arp"]
             fileevent $file readable {set ::arp::remote(busy) 0}
             vwait ::arp::remote(busy)                                                                       ;# allow GUI interaction
