@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: cpustats.tcl,v 1.20 1999/07/23 21:26:40 jfontain Exp $}
+set rcsId {$Id: cpustats.tcl,v 1.21 1999/08/01 12:59:55 jfontain Exp $}
 
 
-package provide cpustats 1.5
+package provide cpustats 1.6
 package require network 1.3
 
 namespace eval cpustats {
@@ -18,23 +18,14 @@ namespace eval cpustats {
         3,label nice 3,type real 3,message {percentage spent in nice mode}
         4,label idle 4,type real 4,message {percentage spent in idle mode}
         columns 5
-        helpText {
-This is a view of processor activity for the system as a whole.
-
-Module options:
-
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host. The module title is set to "cpustats(host)".
-
-Examples:
-
-$ moodss ps -r jdoe@foo.bar.com
-$ moodss ps --remote foo.bar.com
-        }
         views {
             {visibleColumns {1 2 3 4} sort {1 increasing}}
         }
         switches {-r 1 --remote 1}
     }
+    set file [open [file join $::packageDirectory(cpustats) cpustats.htm]]
+    set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
