@@ -1,6 +1,5 @@
 set htmlHelpContents {
-<HTML>
-<BODY>
+<html><body>
 <ul>
 <li>
 <a href="#about">1. About this document</a></li>
@@ -23,18 +22,76 @@ set htmlHelpContents {
 
 <ul>
 <li>
-<a href="#draganddrop">5.1.1. Drag and drop</a></li>
+<a href="#menus">5.1.1. Menus</a></li>
 
 <ul>
 <li>
-<a href="#dropsites">5.1.1.1. Drop sites</a></li>
+<a href="#menus.file">5.1.1.1. File</a></li>
+
+<ul>
+<li>
+<a href="#menus.file.save">5.1.1.1.1. Save</a></li>
 
 <li>
-<a href="#dragsites">5.1.1.2. Drag sites</a></li>
+<a href="#menus.file.saveas">5.1.1.1.2. Save As</a></li>
+
+<li>
+<a href="#menus.file.exit">5.1.1.1.3. Exit</a></li>
 </ul>
 
 <li>
-<a href="#saving">5.1.2. Saving</a></li>
+<a href="#menus.edit">5.1.1.2. Edit</a></li>
+
+<ul>
+<li>
+<a href="#menus.edit.configuration">5.1.1.2.1. Configuration</a></li>
+
+<li>
+<a href="#menus.edit.new">5.1.1.2.2. New</a></li>
+
+<li>
+<a href="#menus.edit.preferences">5.1.1.2.3. Preferences</a></li>
+</ul>
+
+<li>
+<a href="#menus.view">5.1.1.3. View</a></li>
+
+<ul>
+<li>
+<a href="#menus.view.polltime">5.1.1.3.1. Poll Time</a></li>
+</ul>
+
+<li>
+<a href="#menus.help">5.1.1.4. Help</a></li>
+
+<ul>
+<li>
+<a href="#menus.help.global">5.1.1.4.1. Global</a></li>
+
+<li>
+<a href="#menus.help.modules">5.1.1.4.2. Modules</a></li>
+
+<li>
+<a href="#menus.help.copyright">5.1.1.4.3. Copyright</a></li>
+
+<li>
+<a href="#menus.help.sourceversions">5.1.1.4.4. Source Versions</a></li>
+
+<li>
+<a href="#menus.help.about">5.1.1.4.5. About</a></li>
+</ul>
+</ul>
+
+<li>
+<a href="#draganddrop">5.2.1. Drag and drop</a></li>
+
+<ul>
+<li>
+<a href="#dropsites">5.2.1.1. Drop sites</a></li>
+
+<li>
+<a href="#dragsites">5.2.1.2. Drag sites</a></li>
+</ul>
 </ul>
 
 <li>
@@ -49,12 +106,9 @@ set htmlHelpContents {
 </ul>
 </ul>
 </ul>
-</BODY>
-</HTML>
-}
+</body></html>}
 set htmlHelpData {
-<BODY>
-<HTML>
+<body><html>
 <h3>
 <a NAME="about"></a>1. About this document</h3>
 This document contains general information, reference information and examples
@@ -122,6 +176,8 @@ message area) on all menu items.
 <p>Versions 7.0 and up support per user (on UNIX systems) application wide
 preferences setting.
 <p>Versions 7.99 and up support concurrent instances of the same module.
+<p>Versions 8.1 and up support configuration settings per dashboard, with
+a user interface similar to the preferences interface.
 <p>Since module data access is entirely customizable (through C code, Tcl,
 HTTP, ...) and since several modules can be loaded at once, applications
 for moodss become limitless. For example, comparing a remote database server
@@ -153,7 +209,7 @@ file for more information). You are then all set for using the included
 Linux modules or develop your own modules.
 <p><b><i>Unless you want to work on the moodss source code (not the modules),
 you can skip the rest of this section.</i></b>
-<p>For the current version (8.0), the following packages must be installed
+<p>For the current version (8.1), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <ul>
@@ -169,12 +225,12 @@ the BLT library version 2.4 (at <a href="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp
 
 <div align=right><b>*</b><i> many thanks to the authors for these great
 packages</i></div>
-
-<p><br>The pie widgets, stooop and scwoop libraries are included in the
-self contained <i>moodss</i> application file. Therefore, it is not required
-to install the stooop, scwoop and tkpiechart packages, unless you want
-to work on the moodss source code itself. However, should you want to get
-more information on those extensions, you will find the latest versions:
+The pie widgets, stooop and scwoop libraries are included in the self contained
+<i>moodss</i>
+application file. Therefore, it is not required to install the stooop,
+scwoop and tkpiechart packages, unless you want to work on the moodss source
+code itself. However, should you want to get more information on those
+extensions, you will find the latest versions:
 <ul>
 <li>
 stooop version 3.7 or above</li>
@@ -236,12 +292,12 @@ time, so that an identical dashboard can be relaunched at will.
 <a NAME="userinterface"></a>5.1. User interface</h4>
 Immediately after launch, module(s) is(are) loaded and initialized, with
 corresponding messages displayed in the message area, as follows:
-<center><pre><img SRC="moodss5.gif" height=54 width=234></pre></center>
+<center><pre><img SRC="moodss5.gif" ALT="moodss window view in load mode" height=54 width=234></pre></center>
 Soon after, tabular data is displayed in one or more tkTable widgets with
 the module identifier as title, automatic scroll bars, between the menu
 bar, the drop sites with graphical viewers, summary table, free text and
 trash icons and a message area, as one can see below:
-<center><pre><img SRC="moodss1.gif" ALT="moodss initial main window view" NOSAVE height=515 width=505></pre></center>
+<center><pre><img SRC="moodss1.gif" ALT="moodss initial main window view" height=515 width=505></pre></center>
 The message area is used to display status information, such as when the
 data is being updated, and help information, as the user moves the mouse
 pointer over sensitive areas, such as table column headers. Contextual
@@ -257,38 +313,7 @@ on a group of servers), the initial data tables feature the module name
 followed by an instance number (<i>module&lt;N></i>), or the module identifier
 generated from the module code (<i>cpustats(host.domain.org)</i> for example).
 A lone module keeps his unmodified name as table titles.
-<p>The <i>File</i> menu contains the <i>Save</i>, <i>Save As</i> and <i>Exit</i>
-menu entries, used to save the current configuration (modules and viewers),
-or gracefully quit the moodss application.
-<p>The <i>Edit</i> menu contains the <i>New</i> sub menu (only visible
-when not running in read-only mode, see <a href="#commandline">Command
-line</a>), which allows the creation of empty viewers of any type, and
-the <i>Preferences</i> entry which when selected launches the following
-dialog box:
-<center><pre><img SRC="moodss6.gif" height=200 width=446></pre></center>
-The Preferences dialog box allows the user to change application wide settings,
-saved in a global file (known as an <i>rc</i> file to UNIX people), used
-for initialization when the application is started. Since this file is
-stored in the user home directory (on a UNIX system), it provides a way
-for a user to customize the look, behavior, ... of the moodss application
-in a permanent manner. Further and up-to-date help is always provided in
-the different Preferences dialog box screens.
-<p>The <i>View</i> menu (may not exist, see below) contains the <i>Poll
-time</i> entry which when selected launches the corresponding dialog box,
-as shown below:
-<center><pre><img SRC="moodss2.gif" ALT="poll time dialog box" NOSAVE height=140 width=161></pre></center>
-The user can select a new poll time among the module choices from a spin
-entry widget, or directly type in a new value, as long as it is not smaller
-than the module minimum poll time, in which case a warning message is displayed.
-<p>When several modules are used, the minimum poll time is the greater
-of the minimum poll times of all modules. The default poll time (used when
-moodss is started) is the greater of the default poll times of all modules.
-The available choices in the poll time dialog box is the combination of
-all modules poll times.
-<p>The <i>Poll time</i> menu entry is available only when needed, which
-is not the case if all the loaded modules are asynchronous. If this case,
-the <i>Options</i> menu itself is not displayed.
-<p>Any data displayed in a table can be sorted at any time by simply clicking
+<br>Any data displayed in a table can be sorted at any time by simply clicking
 on a column title. Clicking on the same column title again sorts the data
 in opposite order, thus toggling between increasing and decreasing orders.
 <br>When sorting, the selected column is used as a reference, meaning that
@@ -303,8 +328,8 @@ double arrow on column borders to show this capability.
 <p>Aside from the main tables, graphical and textual viewers can be created
 for monitoring table cell data over time. Viewers can also be deleted,
 data views (such as pie slices, curves, ...) can be added or removed from
-existing viewers, ... These functions are all implemented using the drag
-and drop functionality described below.
+existing viewers, ... These functions are all implemented using the <a href="#draganddrop">drag
+and drop</a> functionality.
 <p>For all viewers, if a module identifier string is required (provided
 by the module, several instances of the same module, ...) for proper cell
 identification, that string will be placed first in the label. For example,
@@ -319,34 +344,34 @@ main window message area.
 <p>*<i>note: if you know of any other nice viewers (like 3D graphs) that
 work with Tcl, please let me know so I can integrate them. Many thanks
 in advance...</i>
-<center><table COLS=2 WIDTH="100%" NOSAVE >
-<tr ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<td NOSAVE>
-<center><pre><img SRC="hgraph.gif" ALT="graph viewer sample" NOSAVE height=200 width=300></pre></center>
+<center><table COLS=2 WIDTH="100%" >
+<tr ALIGN=CENTER VALIGN=CENTER>
+<td>
+<center><pre><img SRC="hgraph.gif" ALT="graph viewer sample" height=200 width=300></pre></center>
 </td>
 
 <td>
-<pre><img SRC="hoverbar.gif" ALT="overlap bar chart viewer sample" NOSAVE height=200 width=300></pre>
+<pre><img SRC="hoverbar.gif" ALT="overlap bar chart viewer sample" height=200 width=300></pre>
 </td>
 </tr>
 
-<tr ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<td NOSAVE>
-<pre><img SRC="hsidebar.gif" ALT="side bar chart viewer sample" NOSAVE height=200 width=300></pre>
+<tr ALIGN=CENTER VALIGN=CENTER>
+<td>
+<pre><img SRC="hsidebar.gif" ALT="side bar chart viewer sample" height=200 width=300></pre>
 </td>
 
 <td>
-<pre><img SRC="hstackbr.gif" ALT="stacked bar chart viewer sample" NOSAVE height=200 width=300></pre>
+<pre><img SRC="hstackbr.gif" ALT="stacked bar chart viewer sample" height=200 width=300></pre>
 </td>
 </tr>
 
-<tr ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<td NOSAVE>
-<pre><img SRC="h2dpie.gif" ALT="2D pie chart viewer sample" NOSAVE height=200 width=300></pre>
+<tr ALIGN=CENTER VALIGN=CENTER>
+<td>
+<pre><img SRC="h2dpie.gif" ALT="2D pie chart viewer sample" height=200 width=300></pre>
 </td>
 
 <td>
-<pre><img SRC="h3dpie.gif" ALT="3D pie chart viewer sample" NOSAVE height=200 width=300></pre>
+<pre><img SRC="h3dpie.gif" ALT="3D pie chart viewer sample" height=200 width=300></pre>
 </td>
 </tr>
 </table></center>
@@ -368,20 +393,20 @@ and Backspace keys, which also work on the regular text, as well as the
 expected other key bindings. When dropping data cells, each data cell window
 is preceded by a relevant label text for the cell, which can later be edited
 at any time.
-<center><table WIDTH="100%" NOSAVE >
-<tr ALIGN=CENTER VALIGN=CENTER NOSAVE>
-<td WIDTH="58%" NOSAVE>
-<pre><img SRC="hsumtbl.gif" ALT="summary table viewer sample" NOSAVE height=200 width=350></pre>
+<center><table WIDTH="100%" >
+<tr ALIGN=CENTER VALIGN=CENTER>
+<td WIDTH="58%">
+<pre><img SRC="hsumtbl.gif" ALT="summary table viewer sample" height=200 width=350></pre>
 </td>
 
-<td WIDTH="42%" NOSAVE>
-<pre><img SRC="hfreetxt.gif" ALT="free text viewer sample" NOSAVE height=200 width=250></pre>
+<td WIDTH="42%">
+<pre><img SRC="hfreetxt.gif" ALT="free text viewer sample" height=200 width=250></pre>
 </td>
 </tr>
 </table></center>
 Here is a screen shot of loaded <i>ps</i> and <i>cpustats</i> modules with
 several graphical viewers:
-<center><pre><img SRC="moodss3.gif" ALT="moodss window with graph data viewers" NOSAVE height=553 width=538></pre></center>
+<center><pre><img SRC="moodss3.gif" ALT="moodss window with graph data viewers" height=553 width=538></pre></center>
 All data viewers can be moved and resized thanks to handling areas in the
 data viewer borders. When moving the mouse pointer over these areas, the
 mouse cursor changes to indicate the possible action. Corner handles allow
@@ -397,14 +422,147 @@ small window manager functionality is useless, as it behaves like a basic
 window manager (let me know if it does not).
 <p>Here is another shot featuring a free text viewer with loaded <i>cpustats</i>
 and <i>memstats</i> modules:
-<center><pre><img SRC="moodss4.gif" ALT="moodss window with free text data viewer" NOSAVE height=509 width=493></pre></center>
-The <i>Help</i> menu contains <i>Global</i> help (actually launches an
-embedded HTML viewer with this very document minus the sections related
-to module development), <i>Modules</i> menu with one sub menu per module
-(which displays the module's help data), <i>Copyright</i> which displays
-the GPL (Gnu General Public License) document, <i>Source Versions </i>which
-display all the source code file names with their versions and <i>About</i>
-general information entries.
+<center><pre><img SRC="moodss4.gif" ALT="moodss window with free text data viewer" height=509 width=493></pre></center>
+
+<h5>
+<a NAME="menus"></a>5.1.1. Menus</h5>
+
+<h6>
+<a NAME="menus.file"></a>5.1.1.1. File</h6>
+
+<h6>
+<a NAME="menus.file.save"></a>5.1.1.1.1. Save</h6>
+The current application configuration (including existing data viewers)
+can be saved in a file, which achieves a dashboard functionality.
+<p>Once moodss has been launched with one or several modules and tables
+have been moved, resized, viewers created, moved and resized, the current
+configuration can be saved in a .moo file, and later reused by passing
+the corresponding file name with the <i>-f (--file)</i> command line switch.
+<p>For moodss version 4.0 and above, the following information is saved
+in the file (which is human readable):
+<ul>
+<li>
+moodss version</li>
+
+<li>
+date and time</li>
+
+<li>
+application window size</li>
+
+<li>
+poll time</li>
+
+<li>
+modules</li>
+
+<li>
+tables positions and sizes</li>
+
+<li>
+viewers types, positions, sizes and specific data</li>
+</ul>
+For moodss version 5.1 and above, the following information is also saved:
+<ul>
+<li>
+table viewers column widths</li>
+</ul>
+For moodss version 5.2 and above, the following information is also saved:
+<ul>
+<li>
+viewers stacking order (for internal window manager)</li>
+</ul>
+For moodss version 8.1 and above, the following information is also saved:
+<ul>
+<li>
+global configuration (such as canvas color, sizes, ...) (see <i>Edit</i>
+menu)</li>
+</ul>
+When using this menu for the first time, and if a file name was not specified
+in the command line, the file selector dialog box appears so that the user
+may choose a file name (with a <i>.moo</i> extension).
+<p>Once a file name has been specified (either through the command line
+or the file selector dialog box), that file name is reused whenever the
+<i>File
+Save</i> menu is used.
+<h6>
+<a NAME="menus.file.saveas"></a>5.1.1.1.2. Save As</h6>
+This menu behaves as expected, with the user always having to choose a
+file name using the file selector dialog box (see <i>Save</i> menu above).
+<br>This menu may be used at any time to change the current save file name.
+<h6>
+<a NAME="menus.file.exit"></a>5.1.1.1.3. Exit</h6>
+Use this menu to gracefully quit the moodss application.
+<h6>
+<a NAME="menus.edit"></a>5.1.1.2. Edit</h6>
+
+<h6>
+<a NAME="menus.edit.configuration"></a>5.1.1.2.1. Configuration</h6>
+When selected, this menu launches the following dialog box:
+<center><pre><img SRC="moodss6.gif" height=200 width=446></pre></center>
+The Configuration dialog box allows the user to change global settings
+for the current view (also called a dashbord). This data is stored along when
+saving the configuration to a file (see <a href="#menus.file.save">Save</a> menu).
+<p>Changing configuration choices do not affect the <a href="#menus.edit.preferences">Preferences</a> choices.
+<p>Further and up-to-date help is always provided in the different Configuration
+dialog box screens.
+<h6>
+<a NAME="menus.edit.new"></a>5.1.1.2.2. New</h6>
+Allows the creation of empty viewers of any type (graph chart, overlap bar chart, side bar chart, stacked bar chart, 2D pie chart, 3D pie chart, summary table or free text).
+<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command line</a>).
+<h6>
+<a NAME="menus.edit.preferences"></a>5.1.1.2.3. Preferences</h6>
+The Preferences dialog box is very similar to the <a href="#menus.edit.configuration">configuration</a> dialog
+box.
+<br>It allows the user to change application wide settings, saved in a
+global file (known as an <i>rc</i> file to UNIX people), used for initialization
+when the application is started. Since this file is stored in the user
+home directory (on a UNIX system), it provides a way for a user to customize
+the look, behavior, ... of the moodss application in a permanent manner.
+<p>Preferences choices, when applied (either by choosing Apply or OK) also
+affect <a href="#menus.edit.configuration">configuration</a> settings.
+<p>Further and up-to-date help is always provided in the different Preferences
+dialog box screens.
+<h6>
+<a NAME="menus.view"></a>5.1.1.3. View</h6>
+
+<h6>
+<a NAME="menus.view.polltime"></a>5.1.1.3.1. Poll Time</h6>
+The <i>View</i> menu (may not exist, see below) contains the <i>Poll Time</i>
+entry which when selected launches the corresponding dialog box, as shown
+below:
+<center><pre><img SRC="moodss2.gif" ALT="poll time dialog box" height=140 width=161></pre></center>
+The user can select a new poll time among the module choices from a spin
+entry widget, or directly type in a new value, as long as it is not smaller
+than the module minimum poll time, in which case a warning message is displayed.
+<p>When several modules are used, the minimum poll time is the greater
+of the minimum poll times of all modules. The default poll time (used when
+moodss is started) is the greater of the default poll times of all modules.
+The available choices in the poll time dialog box is the combination of
+all modules poll times.
+<p>The <i>Poll time</i> menu entry is available only when needed, which
+is not the case if all the loaded modules are asynchronous. If this case,
+the <i>Options</i> menu itself is not displayed.
+<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command line</a>).
+<h6>
+<a NAME="menus.help"></a>5.1.1.4.&nbsp; Help</h6>
+
+<h6>
+<a NAME="menus.help.global"></a>5.1.1.4.1. Global</h6>
+This menu launches an embedded HTML viewer with this very document minus
+the sections related to module development.
+<h6>
+<a NAME="menus.help.modules"></a>5.1.1.4.2. Modules</h6>
+This menu features one sub menu per module,&nbsp; which when selected displays the module's help data.
+<h6>
+<a NAME="menus.help.copyright"></a>5.1.1.4.3. Copyright</h6>
+Displays the GPL (Gnu General Public License) document, a truly great idea from the Free Software Foundation.
+<h6>
+<a NAME="menus.help.sourceversions"></a>5.1.1.4.4. Source Versions</h6>
+Displays all the source code file names with their versions, in a table with sort-able columns (as in table viewers).
+<h6>
+<a NAME="menus.help.about"></a>5.1.1.4.5. About</h6>
+Displays version, author, extension authors, license and basic information about moodss.
 <h5>
 <a NAME="draganddrop"></a>5.1.1 Drag and drop</h5>
 Drag and drop in moodss tries to behave as the now familiar Windows functionality
@@ -499,58 +657,6 @@ data, which allows quick viewer mutation (see mechanism description in
 sites</a>).
 <p>The trash icon is also a drag site of the killing action type, which
 allows viewer destruction in one shot.
-<h5>
-<a NAME="saving"></a>5.1.2 Saving</h5>
-The current application configuration (including existing data viewers)
-can be saved in a file, which achieves a dashboard functionality.
-<p>Once moodss has been launched with one or several modules and tables
-have been moved, resized, viewers created, moved and resized, the current
-configuration can be saved in a .moo file, and later reused by passing
-the corresponding file name with the -f (--file) command line switch.
-<p>For moodss version 4.0 and above, the following information is saved
-in the file (which is human readable):
-<ul>
-<li>
-moodss version</li>
-
-<li>
-date and time</li>
-
-<li>
-application window size</li>
-
-<li>
-poll time</li>
-
-<li>
-modules</li>
-
-<li>
-tables positions and sizes</li>
-
-<li>
-viewers types, positions, sizes and specific data</li>
-</ul>
-For moodss version 5.1 and above, the following information is also saved:
-<ul>
-<li>
-table viewers column widths</li>
-</ul>
-For moodss version 5.2 and above, the following information is also saved:
-<ul>
-<li>
-viewers stacking order (for internal window manager)</li>
-</ul>
-When using the <i>File Save</i> menu for the first time, and if a file
-name was not specified in the command line, the file selector dialog box
-appears so that the user may choose a file name (with a .moo extension).
-<p>The <i>File Save As</i> menu behaves as expected, with the user always
-having to choose a file name.
-<p>Once a file name has been specified (either through the command line
-or the file selector dialog box), that file name is reused whenever the
-<i>File
-Save</i> menu is used. The <i>File Save As</i> menu may be used at any
-time to change the file name.
 <h4>
 <a NAME="commandline"></a>5.2. Command line</h4>
 
@@ -628,7 +734,6 @@ with the module options.
 <p>The moodss core checks the validity of module options according to the
 information provided by the module programmer. Any invalid option / value
 combination for the module is detected, reported on the standard error
-channel before the application exits.
 </body>
 </html>
 }
