@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: memstats.tcl,v 1.11 1999/07/23 21:26:40 jfontain Exp $}
+set rcsId {$Id: memstats.tcl,v 1.12 1999/08/01 12:59:55 jfontain Exp $}
 
 
-package provide memstats 1.4
+package provide memstats 1.5
 package require network 1.3
 
 namespace eval memstats {
@@ -20,20 +20,11 @@ namespace eval memstats {
         6,label cached 6,type integer 6,message {cached memory}
         columns 7
         sort {0 increasing}
-        helpText {
-This is a view of memory and swap statistics for the system as a whole.
-
-Module options:
-
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host. The module title is set to "memstats(host)".
-
-Examples:
-
-$ moodss ps -r jdoe@foo.bar.com
-$ moodss ps --remote foo.bar.com
-        }
         switches {-r 1 --remote 1}
     }
+    set file [open [file join $::packageDirectory(memstats) memstats.htm]]
+    set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
