@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: modules.tcl,v 1.18 1999/07/23 21:16:28 jfontain Exp $}
+set rcsId {$Id: modules.tcl,v 1.19 1999/08/01 12:34:27 jfontain Exp $}
 
 class modules {
 
@@ -86,16 +86,15 @@ class modules {
         if {[catch {set ${namespace}::data(helpText)} text]} {
             set text {no help available}
         }
-        set header "<H6>module $namespace</H6>\n<I>version $modules::($namespace,version)"
+        set header "<h6>module $namespace</h6><i>version $modules::($namespace,version)"
         if {[string length $modules::($namespace,arguments)]>0} {
             append header ", invoked with arguments: $modules::($namespace,arguments)"
         }
-        append header </I><BR><BR>\n
-        if {[string first <BODY> $text]<0} {                                                                         ;# regular help
-            regsub -all \n $text <BR> text                                                               ;# keep original formatting
+        append header </i><br><br>
+        if {[regsub -nocase <body> $text <body>$header text]==0} {                           ;# insert header if HTML formatted help
+            regsub -all \n $text <br> text                                                 ;# regular help, keep original formatting
             return ${header}$text
         } else {                                                                                              ;# HTML formatted help
-            regsub <BODY> $text <BODY>\n$header text                                                                ;# insert header
             return $text
         }
     }
