@@ -12,7 +12,7 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.173 1999/07/21 18:50:24 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.176 1999/08/08 19:33:47 jfontain Exp $}
 
 
 proc printUsage {exitCode} {
@@ -67,7 +67,8 @@ if {[info exists arguments(--version)]} {
 }
 
 source preferen.tcl
-preferences::load                                                                     ;# initialize from rc file as soon as possible
+source config.tcl
+configuration::load [preferences::read]                                               ;# initialize from rc file as soon as possible
 
 lappend auto_path /usr/lib/moodss .    ;# search in current directory sub-directories for development and rpm installation directory
 
@@ -148,6 +149,7 @@ if {[info exists arguments(-f)]} {
     set global::saveFile $arguments(-f)
     set initializer [new record -file $global::saveFile]
     record::read $initializer
+    configuration::load [record::configurationData $initializer]                                 ;# set global values from save file
     modules::parse [record::modulesWithArguments $initializer]
     set modules::(initialized) [record::modules $initializer]
 } else {
