@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: mounts.tcl,v 1.8 1999/07/23 21:26:40 jfontain Exp $}
+set rcsId {$Id: mounts.tcl,v 1.9 1999/08/01 12:59:55 jfontain Exp $}
 
 
-package provide mounts 1.4
+package provide mounts 1.5
 package require filesystem
 package require network 1.3
 
@@ -20,40 +20,11 @@ namespace eval mounts {
         5,label available 5,type integer 5,message {available user space in KiloBytes}
         6,label capacity 6,type integer 6,message {used user space in percent}
         sort {0 increasing}
-        helpText {
-This is a view of mounted filesystems with sizes (provided you have a 2.0 or later kernel with the proc filesystem compiled in).
-
-
-Filesystem types are (from the fstab manual page):
-
-
-* minix:  a local filesystem, supporting filenames of length 14 or 30 characters.
-
-* ext:  a local filesystem with longer filenames and larger inodes (has been replaced by the ext2 file system).
-
-* ext2:  a local filesystem with longer filenames, larger inodes, and lots of other features.
-
-* xiafs:  a local filesystem with longer filenames, larger inodes, and lots of other features.
-
-* msdos:  a local filesystem for MS-DOS partitions.
-
-* hpfs:  a local filesystem for HPFS partitions.
-
-* iso9660:  a local filesystem used for CD-ROM drives.
-
-* nfs:  a filesystem for mounting partitions from remote systems.
-
-Module options:
-
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host. The module title is set to "mounts(host)".
-
-Examples:
-
-$ moodss mounts -r jdoe@foo.bar.com
-$ moodss mounts --remote foo.bar.com
-        }
         switches {-r 1 --remote 1}
     }
+    set file [open [file join $::packageDirectory(mounts) mounts.htm]]
+    set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
