@@ -1,14 +1,13 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: ps.tcl,v 1.38 1999/07/24 10:59:11 jfontain Exp $}
+set rcsId {$Id: ps.tcl,v 1.39 1999/08/01 12:59:55 jfontain Exp $}
 
 
 # System dependent process data access procedures. Only Linux is supported at this time (who needs another OS?).
 # Corresponding pkgIndex.tcl file content: package ifneeded ps 1.4 "source [file join $dir ps.tcl]"
-proc echo {args} {foreach argument $args {puts -nonewline "$argument "}; puts {}}
 
-package provide ps 1.7
+package provide ps 1.8
 package require network 1.3
 
 namespace eval ps {
@@ -24,25 +23,15 @@ namespace eval ps {
         6,label status 6,type ascii 6,message {state: Running, Sleeping (D: uninterruptible), Zombie, Traced (or stopped)}
         7,label name 7,type dictionary 7,message {filename of the executable} 7,anchor left
         8,label {command line} 8,type dictionary 8,message {full command line} 8,anchor left
-        helpText {
-This is a view of processor activity, presented in 2 tables, one featuring the full command line.
-In the first table, tasks running on the system are initially sorted, with the most CPU intensive first.
-
-Module options:
-
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host. The module title is set to "ps(host)".
-
-Examples:
-
-$ moodss ps -r jdoe@foo.bar.com
-$ moodss ps --remote foo.bar.com
-        }
         views {
             {visibleColumns {0 1 2 3 4 5 6 7} sort {2 decreasing}}
             {visibleColumns {0 7 8} sort {7 increasing}}
         }
         switches {-r 1 --remote 1}
     }
+    set file [open [file join $::packageDirectory(ps) ps.htm]]
+    set data(helpText) [read $file]
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
