@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: route.tcl,v 1.13 1999/07/23 21:26:40 jfontain Exp $}
+set rcsId {$Id: route.tcl,v 1.15 1999/08/01 12:59:55 jfontain Exp $}
 
 
-package provide route 1.3
+package provide route 1.4
 package require network 1.3
 
 namespace eval route {
@@ -20,24 +20,11 @@ namespace eval route {
         6,label use 6,type integer 6,message {count of lookups for the route}
         7,label metric 7,type integer 7,message {distance (in hops) to the target}
         sort {1 increasing}
-        helpText {
-This is a view of network routes for the system (tested on IPv4 only).
-Networks and hosts addresses are looked up and converted to official names when possible.
-
-Module options:
-
--n (--numeric): display numerical addresses instead of trying to determine symbolic host or network names.
--r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host.
-
-Examples:
-
-$ moodss route --numeric
-$ moodss -- route -n
-$ moodss route -r jdoe@foo.bar.com
-$ moodss route --remote foo.bar.com
-        }
         switches {-n 0 --numeric 0 -r 1 --remote 1}
     }
+    set file [open [file join $::packageDirectory(route) route.htm]]
+    set data(helpText) [read $file]                                                           ;# initialize HTML help data from file
+    close $file
 
     proc initialize {optionsName} {
         upvar $optionsName options
@@ -51,6 +38,7 @@ $ moodss route --remote foo.bar.com
             set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
             foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
             network::checkRemoteOutputEmptiness $remote(host)
+            set data(identifier) route($remote(host))
             set file [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/route"]
             fileevent $file readable {set ::route::remote(busy) 0}
             vwait ::route::remote(busy)                                                                     ;# allow GUI interaction
