@@ -1,11 +1,12 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: sumtable.tcl,v 1.16 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: sumtable.tcl,v 1.20 1999/07/23 20:44:32 jfontain Exp $}
 
 class summaryTable {
 
     set summaryTable::(nextDataIndex) 0              ;# used when data array index is not specified as an option when creating table
+    set summaryTable::(void) 000000          ;# must look void but be a valid number since it may be dropped in another viewer as is
 
     proc summaryTable {this parentPath args} composite {[new frame $parentPath] $args} viewer {} {
         composite::complete $this
@@ -15,7 +16,7 @@ class summaryTable {
         array set $summaryTable::($this,dataName) {
             updates 0
             0,label data 0,type ascii 0,message {data cell description}
-            1,label current 1,type real 1,message {current value}
+            1,label current 1,type real 1,message {current value (000000 means void)}
             2,label average 2,type real 2,message {average value since viewer creation}
             3,label minimum 3,type real 3,message {minimum value since viewer creation}
             4,label maximum 4,type real 4,message {maximum value since viewer creation}
@@ -25,9 +26,10 @@ class summaryTable {
         set summaryTable::($this,nextRow) 0
 
         # wait till after completion before creating table since some options are not dynamically settable
+        # use column widths which may have been set at this summary table construction time when data table did not exist yet
         set table [new dataTable $widget::($this,path)\
             -data summaryTable::$summaryTable::($this,dataName) -draggable $composite::($this,-draggable)\
-            -titlefont $composite::($this,-titlefont)\
+            -titlefont $composite::($this,-titlefont) -columnwidths $composite::($this,-columnwidths)\
         ]
         ### hack: drag and drop code should be separated from dataTable which should provide a selected member procedure ###
         # allow dropping of data cells ### use same path as drag path to avoid drops in table from table ###
@@ -70,6 +72,7 @@ class summaryTable {
     proc options {this} {
         # data index must be forced so that initialization always occur
         return [list\
+            [list -columnwidths columnWidths ColumnWidths {} {}]\
             [list -dataindex {}]\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
@@ -77,6 +80,12 @@ class summaryTable {
         ]
     }
 
+    proc set-columnwidths {this value} {
+        # data table may not have been built if option was passed at construction time
+        if {![info exists summaryTable::($this,dataTable)]} return
+        composite::configure $summaryTable::($this,dataTable) -columnwidths $value
+    }
+
     # data array name index must be specifiable so that data viewers depending on summary table data array name (through their
     # monitored cells) do not fail accessing that data (required when generating viewers from save file)
     proc set-dataindex {this value} {
@@ -119,7 +128,8 @@ class summaryTable {
 
         set row $summaryTable::($this,nextRow)                                                       ;# next row for this data table
         set ${dataName}($row,0) $label
-        array set $dataName [list $row,2 {} $row,3 {} $row,4 {}]          ;# initialize average, minimum and maximum to empty values
+        # initialize average, minimum and maximum
+        array set $dataName [list $row,2 $summaryTable::(void) $row,3 $summaryTable::(void) $row,4 $summaryTable::(void)]
         set ${dataName}($row,sum) 0.0
         set ${this}cellRow($cell) $row                                                                          ;# remember cell row
         # setup action when a row is deleted through a cell drop in trash
@@ -133,9 +143,10 @@ class summaryTable {
 
         foreach cell [array names ${this}cellRow] {
             set row [set ${this}cellRow($cell)]
-            if {[catch {set $cell} current]} {                                                                ;# cell does not exist
-                set ${dataName}($row,1) ?                                 ;# do not touch other columns as their content stays valid
-            } else {
+            if {[catch {set $cell} current]||([string compare $current $summaryTable::(void)]==0)} {
+                # cell does not exist or is another summary table void cell, so propagate here
+                set ${dataName}($row,1) $summaryTable::(void)           ;# do not touch other columns as their content remains valid
+            } else {                                                                                                ;# data is valid
                 set ${dataName}($row,1) $current
                 set ${dataName}($row,2) [format %.2f\
                     [expr\
@@ -143,11 +154,11 @@ class summaryTable {
                     ]\
                 ]
                 set value [set ${dataName}($row,3)]
-                if {([string length $value]==0)||($current<$value)} {
+                if {([string compare $value $summaryTable::(void)]==0)||($current<$value)} {        ;# eventually initialize minimum
                     set ${dataName}($row,3) $current
                 }
                 set value [set ${dataName}($row,4)]
-                if {([string length $value]==0)||($current>$value)} {
+                if {([string compare $value $summaryTable::(void)]==0)||($current>$value)} {        ;# eventually initialize maximum
                     set ${dataName}($row,4) $current
                 }
             }
@@ -193,6 +204,13 @@ class summaryTable {
     # data index is needed so that data array that other eventual data viewers depend on is reused when initializing from save file
     proc initializationConfiguration {this} {
         scan $summaryTable::($this,dataName) %u index                                       ;# retrieve leading index from data name
-        return [list -dataindex $index]
+        set list [list -dataindex $index]
+        foreach {option value} [dataTable::initializationConfiguration $summaryTable::($this,dataTable)] {          ;# in data table
+            if {[string compare $option -columnwidths]==0} {                                        ;# look for column widths option
+                lappend list -columnwidths $value
+                break                                                                                                        ;# done
+            }
+        }
+        return $list
     }
 }
